clear *
version 12.1

u "buffer12.dta", clear

* REAL VARIABLES

g CPI = 0.969 if JAHR == 2003
replace CPI = 0.985 if JAHR == 2004
replace CPI = 1.0 if JAHR == 2005
replace CPI = 1.016 if JAHR == 2006
replace CPI = 1.039 if JAHR == 2007
la var CPI "CPI (in decimal form)"
g REALGNP = GNP / CPI
g RINCHH = INCHH / CPI
	
* LOGS OF REAL INCOME AND REAL GNP
	
foreach v of varlist RINCHH REALGNP {
	g LN`v' = ln(`v')
	la var LN`v' "= ln(`v')"
}

* LOGS OF CRIME VARIABLES

foreach v of varlist CRIMETOT WOHNUNG AUTO KV DROGEN {
	g LN`v' = ln(`v')
	la var LN`v' "= ln(`v')"
}

* DUMMY: BASE HAD A CLOSURE

bys AGS: egen CLOSURE1 = max(CLOSURE)
la var CLOSURE1 "= 1 if Gemeinde experienced base closure"

* YEAR DUMMIES

tab JAHR, g(JAHRD)

* RESCALE SOME VARIABLES

replace REALGNP = REALGNP / 100000
replace CRM = CRM * 10000

xtset AGS JAHR
sort AGS KREISNR JAHR

foreach v of varlist RINCHH UNEMPPROP FOREIGNPROP YNGSH REALGNP CRM {
	di ""
	di as inp "TWO-GROUP MEAN-COMPARISON TEST: `v'"
	ttest `v' if JAHR == 2003, by(CLOSURE1)
	ttest `v' if JAHR == 2007, by(CLOSURE1)
}

* RESCALING

replace DP = DP / 1000

bys AGS: g LREALGNP = REALGNP[_n-1]
bys AGS: g LRELINCHH = RELINCHH[_n-1]
bys AGS: g LUNEMPPROP = UNEMPPROP[_n-1]

*-----------
* POOLED OLS
*-----------

* TOTAL CRIME

	reg LNCRIMETOT DP LREALGNP LRELINCHH FOREIGNPROP UNEMPPROP POP YNGSH OST JAHRD2-JAHRD5, cl(AGS)
	
* WOHNUNGSEINBRUCHDIEBSTAHL

	reg LNWOHNUNG DP LREALGNP LRELINCHH FOREIGNPROP UNEMPPROP POP YNGSH OST JAHRD2-JAHRD5, cl(AGS)

* DIEBSTAHL IN/AUS KRAFTFAHRZEUGEN

	reg LNAUTO DP LREALGNP LRELINCHH FOREIGNPROP UNEMPPROP POP YNGSH OST JAHRD2-JAHRD5, cl(AGS)

* KRPERVERLETZUNG

	reg LNKV DP LREALGNP LRELINCHH FOREIGNPROP UNEMPPROP POP YNGSH OST JAHRD2-JAHRD5, cl(AGS)

* RAUSCHGIFTDELIKTE

	reg LNDROGEN DP LREALGNP LRELINCHH FOREIGNPROP UNEMPPROP POP YNGSH OST JAHRD2-JAHRD5, cl(AGS)

*--------------------------
* FIXED-EFFECTS REGRESSIONS
*--------------------------

* TOTAL CRIME

	xtreg LNCRIMETOT DP LREALGNP LRELINCHH FOREIGNPROP UNEMPPROP POP YNGSH JAHRD3-JAHRD5, fe r
	
* WOHNUNGSEINBRUCHDIEBSTAHL

	xtreg LNWOHNUNG DP LREALGNP LRELINCHH FOREIGNPROP UNEMPPROP POP YNGSH JAHRD3-JAHRD5, fe r

* DIEBSTAHL IN/AUS KRAFTFAHRZEUGEN

	xtreg LNAUTO DP LREALGNP LRELINCHH FOREIGNPROP UNEMPPROP POP YNGSH JAHRD3-JAHRD5, fe r

* KRPERVERLETZUNG

	xtreg LNKV DP LREALGNP LRELINCHH FOREIGNPROP UNEMPPROP POP YNGSH JAHRD3-JAHRD5, fe r

* RAUSCHGIFTDELIKTE

	xtreg LNDROGEN DP LREALGNP LRELINCHH FOREIGNPROP UNEMPPROP POP YNGSH JAHRD3-JAHRD5, fe r
